Helper Functions
================

The following helper functions can be imported directly from antelop at the top level.

.. autofunction:: antelop.split_trials

.. autofunction:: antelop.upload_rig_json

.. autofunction:: antelop.recompute_masks

.. autofunction:: antelop.insert_nwb
